==> apache-ignite-2.13.0-src.zip: apache-ignite-2.13.0-src/modules/core/src/main/java/org/apache/ignite/internal/cache/query/index/sorted/IndexRow.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.cache.query.index.sorted;

import org.apache.ignite.internal.cache.query.index.sorted.inline.InlineIndexTree;
import org.apache.ignite.internal.cache.query.index.sorted.keys.IndexKey;
import org.apache.ignite.internal.processors.cache.mvcc.MvccVersionAware;
import org.apache.ignite.internal.processors.cache.mvcc.txlog.TxState;
import org.apache.ignite.internal.processors.cache.persistence.CacheDataRow;

import static org.apache.ignite.internal.processors.cache.mvcc.MvccUtils.MVCC_COUNTER_NA;
import static org.apache.ignite.internal.processors.cache.mvcc.MvccUtils.MVCC_CRD_COUNTER_NA;
import static org.apache.ignite.internal.processors.cache.mvcc.MvccUtils.MVCC_OP_COUNTER_NA;

/**
 * Represents an index row stored in a tree.
 */
public interface IndexRow extends MvccVersionAware {
    /**
     * @param idx Index of a key.
     * @return Underlying key by specified index.
     */
    public IndexKey key(int idx);

    /**
     * @return Underlying keys.
     */
    public IndexKey[] keys();

    /**
     * @return Link to a cache row.
     */
    public long link();

    /**
     * @return Schema of an index.
     */
    public InlineIndexRowHandler rowHandler();

    /**
     * @return Cache row.
     */
    public CacheDataRow cacheDataRow();

    // MVCC stuff.

    /** {@inheritDoc} */
    @Override public default long mvccCoordinatorVersion() {
        return MVCC_CRD_COUNTER_NA;
    }

    /** {@inheritDoc} */
    @Override public default long mvccCounter() {
        return MVCC_COUNTER_NA;
    }

    /** {@inheritDoc} */
    @Override public default int mvccOperationCounter() {
        return MVCC_OP_COUNTER_NA;
    }

    /** {@inheritDoc} */
    @Override public default byte mvccTxState() {
        return TxState.NA;
    }

    /**
     * @return {@code True} for rows used for index search (as opposed to rows stored in {@link InlineIndexTree}.
     */
    public boolean indexSearchRow();
}

==> apache-ignite-2.15.0-src.zip: apache-ignite-2.15.0-src/modules/core/src/main/java/org/apache/ignite/internal/cache/query/index/sorted/IndexRow.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.cache.query.index.sorted;

import org.apache.ignite.internal.cache.query.index.sorted.inline.InlineIndexTree;
import org.apache.ignite.internal.cache.query.index.sorted.keys.IndexKey;
import org.apache.ignite.internal.processors.cache.mvcc.MvccVersionAware;
import org.apache.ignite.internal.processors.cache.mvcc.txlog.TxState;
import org.apache.ignite.internal.processors.cache.persistence.CacheDataRow;

import static org.apache.ignite.internal.processors.cache.mvcc.MvccUtils.MVCC_COUNTER_NA;
import static org.apache.ignite.internal.processors.cache.mvcc.MvccUtils.MVCC_CRD_COUNTER_NA;
import static org.apache.ignite.internal.processors.cache.mvcc.MvccUtils.MVCC_OP_COUNTER_NA;

/**
 * Represents an index row stored in a tree.
 */
public interface IndexRow extends MvccVersionAware {
    /**
     * @param idx Index of a key.
     * @return Underlying key by specified index.
     */
    public IndexKey key(int idx);

    /**
     * @return Keys count.
     */
    public int keysCount();

    /**
     * @return Link to a cache row.
     */
    public long link();

    /**
     * @return Schema of an index.
     */
    public InlineIndexRowHandler rowHandler();

    /**
     * @return Cache row.
     */
    public CacheDataRow cacheDataRow();

    // MVCC stuff.

    /** {@inheritDoc} */
    @Override public default long mvccCoordinatorVersion() {
        return MVCC_CRD_COUNTER_NA;
    }

    /** {@inheritDoc} */
    @Override public default long mvccCounter() {
        return MVCC_COUNTER_NA;
    }

    /** {@inheritDoc} */
    @Override public default int mvccOperationCounter() {
        return MVCC_OP_COUNTER_NA;
    }

    /** {@inheritDoc} */
    @Override public default byte mvccTxState() {
        return TxState.NA;
    }

    /**
     * @return {@code True} for rows used for index search (as opposed to rows stored in {@link InlineIndexTree}.
     */
    public boolean indexPlainRow();
}
